@@ -19,7 +19,7 @@ NAME = APIS['nu']
 MAX_ITEMS = 10
 MAX_FILE_AGE = 60 * 10
 
-BASE_URL = 'https://www.fi-api.io/nu/items/'
+BASE_URL = 'https://fi-api.io/news/nu/articles/'
 
 ##################################################################################################
 # LOGGING
@@ -85,13 +85,13 @@ def run_api():
 
             root = ET.fromstring(response.content)
 
-            for image_original in root.iter('image_original'):
+            for image_original in root.iter('media'):
                 if isinstance(image_original.text, str):
                     temp_path = scala.download_media_temp(image_original.text)
                     image_original.text = scala.install_content(
                         temp_path, category)
 
-            for image_square in root.iter('image_square'):
+            for image_square in root.iter('media_sqr'):
                 if isinstance(image_square.text, str):
                     temp_path = scala.download_media_temp(image_square.text)
                     image_square.text = scala.install_content(
