@@ -213,7 +213,10 @@ def get_from(circumstance):
     if text is None:
         return ''
     else:
-        return text.split(' - ')[0]
+        try:
+            return text.split(' - ')[0]
+        except IndexError:
+            return ''
 
 
 def get_to(circumstance):
@@ -221,7 +224,10 @@ def get_to(circumstance):
     if text is None:
         return ''
     else:
-        return text.split(' - ')[1]
+        try:
+            return text.split(' - ')[1]
+        except IndexError:
+            return ''
 
 
 def get_total_jams(jams):
