@@ -1,9 +1,12 @@
+import json
+import os
 import threading
 from typing import Any, Optional
 
 import firebase_admin
-import google.cloud.firestore_v1.client as client
+from google.cloud.firestore import Client
 from firebase_admin import firestore
+from firebase_admin import credentials
 from firstimpression.api.request import give_error_message, request_json
 from firstimpression.scala import ScalaPlayer
 
@@ -22,14 +25,14 @@ class Firebase:
         self.project_id = svars['Player.firebase_project_id']
         self.credentials = self.__get_credentials()
 
-        self.callback_done = threading.Event()
-
         firebase_admin.initialize_app(self.credentials)
 
-        self.db: client.Client  = firestore.client()
+        self.db: Client  = firestore.client()
 
         self.on_snapshot = self.__get_on_snapshot()
 
+        self.callback_done = threading.Event()
+
 
     def __get_on_snapshot(self):
 
@@ -73,10 +76,19 @@ class Firebase:
 
             raise SystemExit
 
-        return response_json
+        response_json: Any
+        response_json = response_json[0]
+        response_json['private_key'] = response_json['private_key'].replace('\\n', '\n')
+        file_path = os.path.join(scala.content_folder, 'cred.json')
+
+
+        with open(file_path, 'w') as f:
+            json.dump(response_json, f)
+
+        return credentials.Certificate(file_path)
 
     def get_query(self):
-        return self.db.collection('triggers').where('player', '==', scala.uuid)
+        return self.db.collection('triggers').where(u"player", u"==", scala.uuid).on_snapshot(self.on_snapshot)
 
 
 def change_triggers(playlist: Optional[str]):
